nbxmpp.stringprepare.LookupTableFromFunction

Package nbxmpp :: Module stringprepare :: Class LookupTableFromFunction |
[hide private]
[frames] | no frames]

# Class LookupTableFromFunction

source code

Nested Classes | [hide private]
| __implements__ Interface for character lookup classes

Instance Methods | [hide private]
__init__(self, in_table_function) | source code

Method Details | [hide private]

### __init__(self, in_table_function) (Constructor) | source code